==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkLabelRenderStrategy.java <==
// java wrapper for vtkLabelRenderStrategy object
//

package vtk;
import vtk.*;

public class vtkLabelRenderStrategy extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SupportsRotation_2();
  public boolean SupportsRotation()
    { return SupportsRotation_2(); }

  private native boolean SupportsBoundedSize_3();
  public boolean SupportsBoundedSize()
    { return SupportsBoundedSize_3(); }

  private native void SetRenderer_4(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_4(id0); }

  private native long GetRenderer_5();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_5();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetDefaultTextProperty_6(vtkTextProperty id0);
  public void SetDefaultTextProperty(vtkTextProperty id0)
    { SetDefaultTextProperty_6(id0); }

  private native long GetDefaultTextProperty_7();
  public vtkTextProperty GetDefaultTextProperty() {
    long temp = GetDefaultTextProperty_7();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void ComputeLabelBounds_8(vtkTextProperty id0,String id1,double id2[]);
  public void ComputeLabelBounds(vtkTextProperty id0,String id1,double id2[])
    { ComputeLabelBounds_8(id0,id1,id2); }

  private native void RenderLabel_9(int id0[],vtkTextProperty id1,String id2);
  public void RenderLabel(int id0[],vtkTextProperty id1,String id2)
    { RenderLabel_9(id0,id1,id2); }

  private native void RenderLabel_10(int id0[],vtkTextProperty id1,String id2,int id3);
  public void RenderLabel(int id0[],vtkTextProperty id1,String id2,int id3)
    { RenderLabel_10(id0,id1,id2,id3); }

  private native void StartFrame_11();
  public void StartFrame()
    { StartFrame_11(); }

  private native void EndFrame_12();
  public void EndFrame()
    { EndFrame_12(); }

  private native void ReleaseGraphicsResources_13(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_13(id0); }

  public vtkLabelRenderStrategy() { super(); }

  public vtkLabelRenderStrategy(long id) { super(id); }

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkLabelRenderStrategy.java <==
// java wrapper for vtkLabelRenderStrategy object
//

package vtk;
import vtk.*;

public class vtkLabelRenderStrategy extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SupportsRotation_2();
  public boolean SupportsRotation()
    { return SupportsRotation_2(); }

  private native boolean SupportsBoundedSize_3();
  public boolean SupportsBoundedSize()
    { return SupportsBoundedSize_3(); }

  private native void SetRenderer_4(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_4(id0); }

  private native long GetRenderer_5();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_5();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDefaultTextProperty_6(vtkTextProperty id0);
  public void SetDefaultTextProperty(vtkTextProperty id0)
    { SetDefaultTextProperty_6(id0); }

  private native long GetDefaultTextProperty_7();
  public vtkTextProperty GetDefaultTextProperty() {
    long temp = GetDefaultTextProperty_7();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ComputeLabelBounds_8(vtkTextProperty id0,String id1,double id2[]);
  public void ComputeLabelBounds(vtkTextProperty id0,String id1,double id2[])
    { ComputeLabelBounds_8(id0,id1,id2); }

  private native void RenderLabel_9(int id0[],vtkTextProperty id1,String id2);
  public void RenderLabel(int id0[],vtkTextProperty id1,String id2)
    { RenderLabel_9(id0,id1,id2); }

  private native void RenderLabel_10(int id0[],vtkTextProperty id1,String id2,int id3);
  public void RenderLabel(int id0[],vtkTextProperty id1,String id2,int id3)
    { RenderLabel_10(id0,id1,id2,id3); }

  private native void StartFrame_11();
  public void StartFrame()
    { StartFrame_11(); }

  private native void EndFrame_12();
  public void EndFrame()
    { EndFrame_12(); }

  private native void ReleaseGraphicsResources_13(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_13(id0); }

  public vtkLabelRenderStrategy() { super(); }

  public vtkLabelRenderStrategy(long id) { super(id); }

}
